[![Gitter](https://badges.gitter.im/atolab/fog05.svg)](https://gitter.im/atolab/fog05?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![License](https://img.shields.io/badge/License-EPL%202.0-blue)](https://choosealicense.com/licenses/epl-2.0/)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![Documentation Status](https://readthedocs.org/projects/eclipse-fog05-python3-sdk/badge/?version=latest)](https://eclipse-fog05-python3-sdk.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.com/eclipse-fog05/sdk-python.svg?branch=master)](https://travis-ci.com/eclipse-fog05/sdk-python)

# Eclispe fog05 SDK Python

This repository contains the Eclipse fog05 SDK for Python

With this SDK you can build plugins or extend Eclipse fog05 functionalities using python code.


## Docs

Documentation is available here: [readthedocs.io](https://eclipse-fog05-python3-sdk.readthedocs.io/en/latest/?badge=latest)
